==> python_web3_wallet-0.0.3-py3-none-any.whl: python_web3_wallet/__init__.py <==
import os
import streamlit.components.v1 as components

_RELEASE = True

# Declare a Streamlit component. `declare_component` returns a function
# that is used to create instances of the component. We're naming this
# function "_component_func", with an underscore prefix, because we don't want
# to expose it directly to users. Instead, we will create a custom wrapper
# function, below, that will serve as our component's public API.

# It's worth noting that this call to `declare_component` is the
# *only thing* you need to do to create the binding between Streamlit and
# your component frontend. Everything else we do in this file is simply a
# best practice.

if not _RELEASE:
    _component_func = components.declare_component(
        # We give the component a simple, descriptive name ("my_component"
        # does not fit this bill, so please choose something better for your
        # own component :)
        "python_web3_wallet",
        # Pass `url` here to tell Streamlit that the component will be served
        # by the local dev server that you run via `npm run start`.
        # (This is useful while your component is in development.)
        url="http://localhost:3001",
    )
else:
    # When we're distributing a production version of the component, we'll
    # replace the `url` param with `path`, and point it to the component's
    # build directory:
    parent_dir = os.path.dirname(os.path.abspath(__file__))
    build_dir = os.path.join(parent_dir, "frontend/build")
    _component_func = components.declare_component("python_web3_wallet", path=build_dir)


# Create a wrapper function for the component. This is an optional
# best practice - we could simply expose the component function returned by
# `declare_component` and call it done. The wrapper allows us to customize
# our component's API: we can pre-process its input args, post-process its
# output value, and add a docstring for users.
def my_component(recipient: str, amount_in_ether: str, data: str, key=None):
    """Create a new instance of "my_component".

    Parameters
    ----------
    recipient: str
        The name of the thing we're saying hello to. The component will display
        the text "Hello, {name}!"
    amount_in_ether: str
        Amount in ether to be transferred.
    data: str
        Hexadecimal-formatted string that will be used to fill the data field of the transaction.

    """
    # Call through to our private component function. Arguments we pass here
    # will be sent to the frontend, where they'll be available in an "args"
    # dictionary.
    #
    component_value = _component_func(recipient=recipient,  amountInEther=amount_in_ether,data=data, key=key)
    return component_value

==> python_web3_wallet-0.0.4-py3-none-any.whl: python_web3_wallet/__init__.py <==
import os
import streamlit.components.v1 as components

_RELEASE = True

# Declare a Streamlit component. `declare_component` returns a function
# that is used to create instances of the component. We're naming this
# function "_component_func", with an underscore prefix, because we don't want
# to expose it directly to users. Instead, we will create a custom wrapper
# function, below, that will serve as our component's public API.

# It's worth noting that this call to `declare_component` is the
# *only thing* you need to do to create the binding between Streamlit and
# your component frontend. Everything else we do in this file is simply a
# best practice.

if not _RELEASE:
    _component_func = components.declare_component(
        # We give the component a simple, descriptive name ("my_component"
        # does not fit this bill, so please choose something better for your
        # own component :)
        "python_web3_wallet",
        # Pass `url` here to tell Streamlit that the component will be served
        # by the local dev server that you run via `npm run start`.
        # (This is useful while your component is in development.)
        url="http://localhost:3001",
    )
else:
    # When we're distributing a production version of the component, we'll
    # replace the `url` param with `path`, and point it to the component's
    # build directory:
    parent_dir = os.path.dirname(os.path.abspath(__file__))
    build_dir = os.path.join(parent_dir, "frontend/build")
    _component_func = components.declare_component("python_web3_wallet", path=build_dir)


# Create a wrapper function for the component. This is an optional
# best practice - we could simply expose the component function returned by
# `declare_component` and call it done. The wrapper allows us to customize
# our component's API: we can pre-process its input args, post-process its
# output value, and add a docstring for users.
def my_component(recipient: str, amount_in_ether: str, data: str | None = None, key=None):
    """Create a new instance of "my_component".

    Parameters
    ----------
    recipient: str
        The name of the thing we're saying hello to. The component will display
        the text "Hello, {name}!"
    amount_in_ether: str
        Amount in ether to be transferred.
    data: str
        Hexadecimal-formatted string that will be used to fill the data field of the transaction.

    """
    # Call through to our private component function. Arguments we pass here
    # will be sent to the frontend, where they'll be available in an "args"
    # dictionary.
    #
    component_value = _component_func(recipient=recipient,  amountInEther=amount_in_ether,data=data, key=key)
    return component_value
